/*
 * This file is part of GDigicam
 *
 * Copyright (C) 2008-2009 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: Alexander Bokovoy <alexander.bokovoy@nokia.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

/**
 * SECTION:gdigicam-version
 * @short_description: Versioning utility macros
 *
 * GDigicam offers a set of macros for checking the version of the library
 * an application was linked to.
 */

#ifndef __G_DIGICAM_VERSION_H__
#define __G_DIGICAM_VERSION_H__

#ifdef __cplusplus
extern "C" {
#endif

    G_BEGIN_DECLS

    /**
     * G_DIGICAM_MAJOR_VERSION:
     *
     * The major version of the GDigicam library (1, if %G_DIGICAM_VERSION is 1.2.3)
     */
#define G_DIGICAM_MAJOR_VERSION   (0)

    /**
     * G_DIGICAM_MINOR_VERSION:
     *
     * The minor version of the GDigicam library (2, if %G_DIGICAM_VERSION is 1.2.3)
     */
#define G_DIGICAM_MINOR_VERSION   (2)

    /**
     * G_DIGICAM_MICRO_VERSION:
     *
     * The micro version of the GDigicam library (3, if %G_DIGICAM_VERSION is 1.2.3)
     */
#define G_DIGICAM_MICRO_VERSION   (40)

    /**
     * G_DIGICAM_VERSION:
     *
     * The full version of the GDigicam library, like 1.2.3
     */
#define G_DIGICAM_VERSION         0.2.40

    /**
     * G_DIGICAM_VERSION_S:
     *
     * The full version of the GDigicam library, in string form (suited for
     * string concatenation)
     */
#define G_DIGICAM_VERSION_S       "0.2.40"

    /**
     * G_DIGICAM_VERSION_HEX:
     *
     * Numerically encoded version of the GDigicam library, like 0x010203
     */
#define G_DIGICAM_VERSION_HEX     ((G_DIGICAM_MAJOR_VERSION << 24) |    \
                                   (G_DIGICAM_MINOR_VERSION << 16) |    \
                                   (G_DIGICAM_MICRO_VERSION << 8))

    /**
     * G_DIGICAM_CHECK_VERSION:
     * @major: major version, like 1 in 1.2.3
     * @minor: minor version, like 2 in 1.2.3
     * @micro: micro version, like 3 in 1.2.3
     *
     * Evaluates to %TRUE if the version of the GDigicam library is greater
     * than @major, @minor and @micro
     */
#define G_DIGICAM_CHECK_VERSION(major,minor,micro)                      \
    (G_DIGICAM_MAJOR_VERSION > (major) ||                               \
     (G_DIGICAM_MAJOR_VERSION == (major) && G_DIGICAM_MINOR_VERSION > (minor)) || \
     (G_DIGICAM_MAJOR_VERSION == (major) && G_DIGICAM_MINOR_VERSION == (minor) && G_DIGICAM_MICRO_VERSION >= (micro)))

    G_END_DECLS

#ifdef __cplusplus
} /* extern "C" */
#endif

#endif /* __G_DIGICAM_VERSION_H__ */
